import { useEffect, useRef } from 'react';
import React from 'react';
import { Modal, Descriptions, Typography, Table } from 'antd';
import apis from '@/services/apis';
import request from '@/utils/request';

const { Title, Paragraph, Text } = Typography;

function agentDeal (props) {
  const { detail, open, onCancel } = props;
  const { personId } = detail || {}

  const [cardList, setCardList] = React.useState([]);

  const columns = [
    {
      title: '开户行',
      dataIndex: 'bankName',
      key: 'bankName',
      render: t => <Text copyable>{t || '-'}</Text>
    },
    {
      title: '卡号',
      dataIndex: 'cardNo',
      key: 'cardNo',
      render: t => <Text copyable>{t || '-'}</Text>
    },
  ]

  useEffect(() => {
    if (personId) {
      request({
        ...apis.broker.getBrokerDetails,
        params: { personId, pageSize: 100 }
      }).then((res) => {
        setCardList(res.records || []);
      });
    }
  }, [personId]);

  return (
    <Modal
      width={800}
      visible={open}
      title={detail.name || detail.nickname || '详情'}
      onCancel={onCancel}
      onOk={onCancel}
      footer={null}
    >
      <Paragraph>
        <h4 style={{ fontSize: '16px', marginBottom: '1em' }}>基础信息</h4>
        <Descriptions column={3}>
          <Descriptions.Item label="姓 名"><Text copyable>{detail.name || detail.nickname || '-'}</Text></Descriptions.Item>
          <Descriptions.Item label="手 机"><Text copyable>{detail.phone || '-'}</Text></Descriptions.Item>
          <Descriptions.Item label="身份证"><Text copyable>{detail.idNo || '-'}</Text></Descriptions.Item>
        </Descriptions>
      </Paragraph>
      <Paragraph style={{ marginTop: '4em' }}>
        <h4 style={{ fontSize: '16px', marginBottom: '1em' }}>银行卡信息</h4>
        <Table
          columns={columns}
          dataSource={cardList}
          rowKey="cardId"
          pagination={false}
        />
      </Paragraph>
    </Modal>
  );
}

export default agentDeal;
